Crate rust_ev_system_library

Crate rust_ev_system_library 

This crate implements functionalities of the E-Voting System of Swiss Post that are necessary for the verifier. It is based on the specifications of Swiss Post, according to the following document version:

It implements only the functionalities that are necessary for the implementation of the Verifier.

See the installation guide of the Crypto Primitives

Modules

chanel_security
preliminaries
Algorithms defined in section Preliminaries
rust_ev_crypto_primitives
Expose rust_ev_crypto_primitives und rust_ev_crypto_primitives::prelude to avoid problems of consistencies
tally_phase
Module implementing the algorithms for the tally phase

Constants

MAX_LENGTH_WRITE_IN_FIELD
Maximum number of characters in a write-in field (l_w)