This crate implements functionalities of the E-Voting System of Swiss Post that are necessary for the verifier. It is based on the specifications of Swiss Post, according to the following document version:
- System Specification, version 1.5.0
It implements only the functionalities that are necessary for the implementation of the Verifier.
See the installation guide of the Crypto Primitives
Modules
- chanel_
security - preliminaries
- Algorithms defined in section Preliminaries
- rust_
ev_ crypto_ primitives - Expose rust_ev_crypto_primitives und rust_ev_crypto_primitives::prelude to avoid problems of consistencies
- tally_
phase - Module implementing the algorithms for the tally phase
Constants
- MAX_
LENGTH_ WRITE_ IN_ FIELD - Maximum number of characters in a write-in field (l_w)